@@ -1,5 +1,5 @@
 import os
-import platform
+import platform as platform_module
 import subprocess
 import textwrap
 from multiprocessing import Pool
@@ -100,7 +100,7 @@ class Host(object):
         :param args: command dict
         :return:
         """
-        hostname = platform.uname()[1]
+        hostname = platform_module.uname()[1]
         host = args.get("host")
 
         shell = args.get("shell")
