@@ -90,6 +90,15 @@ class Console(object):
 
     theme = theme_color
 
+    try:
+        size = os.get_terminal_size()
+        columns = size.columns
+        lines = size.lines
+    except:
+        columns = 79
+        lines = 24
+
+
     def line(self, c="="):
         try:
             size = os.get_terminal_size()
@@ -111,7 +120,7 @@ class Console(object):
 
     # noinspection PyPep8Naming
     def blue(msg):
-        print(Fore.BLLUE + msg + Style.RESET_ALL)
+        print(Fore.BLUE + msg + Style.RESET_ALL)
 
     @staticmethod
     def init():
